package SPVM::R::DataFrame::Column;



1;

=head1 Name

SPVM::R::DataFrame::Column - Column of Data Frame

=head1 Description

R::DataFrame::Column class in L<SPVM> represents a column of a L<data frame|SPVM::R::DataFrame>.

This class is a private class.

=head1 Fields

=head2 name

C<has name : string;>

A column name.

=head2 ndarray

C<has ndarray : L<R::NDArray|SPVM::R::NDArray>;>

A n-dimensional array.

=head1 See Also

=over 2

=item * L<R::DataFrame|SPVM::R::DataFrame>

=item * L<R|SPVM::R>

=back

=head1 Copyright & License

Copyright (c) 2024 Yuki Kimoto

MIT License

